C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LDM_FILENAME     **
C**************************
C
CD-Routine: Get Image File Name From Definition or Template - LDM_FILENAME
C This routine returns the image file name for a given pack and plate. If
C an explicit name has been defined for the file name then this will be
C returned. Otherwise the name will be created from the file name template
C using the pack id and plate number. Full details are given in the parameter
C descriptions for the routine.
CD-end
CD-Fortran:
      SUBROUTINE LDM_FILENAME (IPACK, IPLATE, FILNAM)
CD-end
      INCLUDE 'implicit_none.finc'
C
C Purpose: Get image file name from explicit definition or made up from
C          template.
C
C Author:  John W. Campbell, July 1993
C
C Arguments:
C
      INTEGER IPACK
      INTEGER IPLATE
      CHARACTER*(*) FILNAM

CD-Parameters:
C IPACK      i (R)   Pack number
C IPLATE     i (R)   Plate number
C FILNAM     c (W)   Returns file name
C                    If explicit one present then this is returned. If not
C                    then one is derived from the template which normally
C                    contains a sequence of '#' characters; these are
C                    replaced with the pack_id (+plate identifier) with at 
C                    least as many characters use as '#' characters in the 
C                    sequence. 
C
C                    The pack_id is output as an integer with leading zeros
C                    if needed; If the number of plates in the pack is 
C                    greater than one then the pack_id will be followed by 
C                    the plate letter 1=a, 2=b etc.
C
C                    Examples:
C
C                        1) Template lys####.i2 pack_id=15 1 plate
C                           file name returned = lys0015.od
C
C                        2) Template pf####.od pack_id=12 no. 1 of 6 plates
C                           file name returned = pf012a.od
C                     
C                        3) As above but for 2'nd plate 
C                           file name returned = pf012b.od
C                   
C                        3) Template pf#.od pack_id=12 no. 1 of 6 plates
C                           file name returned = pf12a.od
C
C                    For non-standard cases, the treatments are as follows:
C
C                    If no '#' is present in the template, the pack_id 
C                    (+ plate identifier) will be added just before the 
C                    '.' of file extension; if there is no file extension 
C                    the pack_id (+ plate identifier) will be added at the 
C                    of the template string.
C
C                    If there are more than 26 plates in the pack the plate
C                    identifier will be added as an underscore followed by 
C                    the plate number
CD-end
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
C
C====== FUNCTION TYPES:
C
      INTEGER LENSTR
C
C====== LOCALS:
C
      INTEGER I
      INTEGER J
      INTEGER LL
      INTEGER NDIG
      INTEGER IDEC
      INTEGER IPID
      INTEGER IFLAG
      INTEGER IERR
      CHARACTER*(1) ERRSTR
      CHARACTER*120 STR1
      CHARACTER*120 STR2
      CHARACTER*26 LETTER
      CHARACTER*8 FRM

C     INTEGER I            !Temporary variable/counter
C     INTEGER J            !Temporary variable/counter
C     INTEGER LL           !Significant length of character string
C     INTEGER NDIG         !Minimum no. of digits for pack-id o/p
C     INTEGER IDEC         !Position of last '.' in template string
C     INTEGER IPID         !Pack id
C     INTEGER IFLAG        !Flag from LDM_GET... routine
C     INTEGER IERR         !Error flag
C     CHARACTER*(1) ERRSTR !Dummy error message string
C     CHARACTER*120 STR1   !Temporary string to collect 1'st part for file name
C     CHARACTER*120 STR2   !Temporary string to collect last part for file name
C     CHARACTER*26 LETTER  !Letters of alphabet
C     CHARACTER*8 FRM      !Format string

      DATA FRM /'(I25.XX)'/
      DATA LETTER/'abcdefghijklmnopqrstuvwxyz'/
C
C-------------------------------------------------------------------------------
C
C====== Initialisations
C
      FILNAM = ' '
      IF (IPACK.LT.1.OR.IPACK.GT.LDM_MAXPK) RETURN
      IF (IPLATE.LT.1.OR.IPLATE.GT.LDM_MAXPL) RETURN
C
C====== See if specific name given, if so return it
C
      FILNAM = FNAME(IPACK,IPLATE)
      IF (FILNAM.NE.' ') RETURN
C
C====== Form file name from template (split template into sections and
C       get length of '#' field if present)
C
      NDIG  = 1
      STR1 = ' '
      STR2 = ' '
      IF (TEMPL.NE.' ') THEN
         LL = LENSTR(TEMPL)
         IF (INDEX(TEMPL,'#').GT.0) THEN
            I = 0
            J = 0
10          I = I + 1
               IF (TEMPL(I:I).NE.'#') THEN
                  J = J + 1
                  STR1(J:J) = TEMPL(I:I)
               GO TO 10
            END IF
20          I = I + 1
            IF (I.LE.LL) THEN
               IF (TEMPL(I:I).EQ.'#') THEN
                  NDIG = NDIG + 1
                  GO TO 20
               END IF
            END IF
            IF (I.LE.LL) STR2 = TEMPL(I:LL)
         ELSE
            IDEC = 0
            DO 30 I = LL, 1, -1
               IF (TEMPL(I:I).EQ.'.') THEN
                  IDEC = I
                  GO TO 40
               END IF
30          CONTINUE
            STR1 = TEMPL
            GO TO 50
40          IF (IDEC.GT.1) STR1 = TEMPL(1:IDEC-1)
            STR2 = TEMPL(IDEC:)
         END IF
      END IF
C
C====== Now add pack_id (+ plate letter (or number))
C
50    FILNAM = STR1
      IF (NDIG.GT.1.AND.NPLAT.GT.1) NDIG = NDIG - 1
      WRITE (FRM(6:7),'(I2.2)')NDIG
      CALL LDM_GET_PID (IPACK, IPID, IFLAG, IERR, ERRSTR)
      WRITE (STR1,FRM) IPID
      LL = LENSTR(STR1)
      J = 0
      DO 60 I = 1, LL
         IF (STR1(I:I).NE.' ') THEN
            STR1 = STR1(I:LL)
            GO TO 70
         END IF
60    CONTINUE
70    CALL STR_ADDS(FILNAM,STR1,0)
      IF (NPLAT.GT.1) THEN
         IF (IPLATE.LE.26) THEN
            CALL STR_ADDS(FILNAM,LETTER(IPLATE:IPLATE),0)
         ELSE
            CALL STR_ADDS(FILNAM,'_',0)
            CALL STR_ADDI(FILNAM,IPLATE,0)
         END IF
      END IF
C
C====== Complete name
C
      CALL STR_ADDS (FILNAM,STR2,0)
      RETURN
      END
