CD-Routine: Individual Routines to Get LDM Parameter Values - LDM_GET_...
C These are the individual routines for getting LDM parameter values.
CD-end

CD-doc:
C As there are a large number of routines involved and as these routines 
C have very similar parameters, a general description of the parameters
C is given here and only the list of parameters is given with each
C individual subroutine.
C
C  General description of parameters for 'get' routines:
C
C  KEYWORD    c (R)  Full keyword string (upper case) without any
C                    pack/plate specification.
C  IPACK      i (R)  Pack number (explicit) if relevant for the parameter      
C  IPLATE     i (R)  Plate number (explicit) if relevant for the parameter
C  ICOEFF     i (R)  Coefficient no. if > 0, 0=all coefficients (for 
C                    spatial distortion polynomial parameters only)
C  VALSTR     c (W)  The value returned as a string (max 120 chars)
C  VALUE      r (W)  The parameter value as a real number for 
C                    'real number' parameters.
C  ND         i (W)  The number of decimal places to be printed for 'real
C                    number' parameters (-ve for E format). This may be
C                    the default for the parameter or may be derived
C                    from the value string used to set the parameter value
C                    (see the LDM parameter value setting routines)
C  IVAL       i (W)  The parameter value as an integer for integer 
C                    parameters
C  SVAL()     r (W)  Returns polynomial coefficients (for the spatial 
C                    parameters only).
C                    (if ICOEFF.GT.0 value is returned in SVAL(1))
C                    (if ICOEFF.EQ.0 dimension to at least LDM_MAXSPD)
C  IFLAG      i (W)  The status of the parameter value =-1 undefined
C                                                      = 0 default
C                                                      = 1 set explicitly 
C                                                      = 2 set globally
C  ITYP       i (W)  = 0 string value returned
C                    = 1 string value and integer code
C                    = 2 integer value (string also returned)
C                    = 3 real value (string also returned)
C  IERR       i (W)  Error flag =  0 OK
C                               =  1 Invalid keyword
C                               = -1 Invalid pack number
C                               = -2 Invalid plate number
C                               = -3 Invalid polynomial coefficient number
C  ERRSTR     c (W)  Returns string for error message (max. 80 chars)
C
C Routines:
C
CD-end
C
C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LDM_GET_CRYST    **
C**************************
C
C
CD-Doc:
C CRYStal          SUBROUTINE LDM_GET_CRYST (VALSTR, IFLAG)
CD-end
      SUBROUTINE LDM_GET_CRYST (VALSTR, IFLAG)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Get value of string parameter CRYSTAL
C
C Author:  John W. Campbell, June 1993
C
C Arguments:
C
      CHARACTER*(*) VALSTR
      INTEGER IFLAG

C  VALSTR    (W)   Value for the parameter (up to 50 chars)
C  IFLAG     (W)   Flag = -1 undefined value
C                       =  0 default value
C                       =  1 value set explicitly
C                       =  2 value set globally
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C

C
C-------------------------------------------------------------------------------
C
      VALSTR = CRYST
      IFLAG = IS_CRYST
      RETURN
      END
