C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LFN_UNQ_STAT     **
C**************************
C
CD-Routine: Statistics Relative to Unique Data - LFN_UNQ_STAT
C This routine resturns statistics based on the current counts of
C reflections marked in the unique reflections list using the LFN_UNQ_INC
C routine. The statistics are in bins of 4*sin**2theta/lambda**2.
CD-end
CD-Fortran:
      SUBROUTINE LFN_UNQ_STAT (NBIN, SPAT, RESMIN, RESMAX, 
     +                         NCOUNT, NCOUNT_TOT, 
     +                         PERCENT, PERCENT_TOT, IERR)
CD-end
      INCLUDE 'implicit_none.finc'
C
C Purpose: Statistics on Laue data wrt. unique data in bins of
C          4*sin**2theta/lambda**2
C
C Author:  John W. Campbell, September 1993
C
C Arguments:
C
      INTEGER NBIN
      LOGICAL SPAT
      REAL RESMIN(*)
      REAL RESMAX(*)
      INTEGER NCOUNT(10,*)
      INTEGER NCOUNT_TOT(*)
      REAL PERCENT(10,*)
      REAL PERCENT_TOT(*)
      INTEGER IERR
CD-Parameters:
C NBIN               i (R)   No. of 4*sin**2theta/lambda**2 bins
C SPAT               l (R)   =.TRUE.  include spatially overlapped data,
C                            =.FALSE. do not
C RESMIN(10,NBIN)    r (W)   Start resolution of bins
C RESMAX(10,NBIN)    r (W)   End resolution of bins
C NCOUNT(10,NBIN)    i (W)   No. counts for each bin (see also below)
C NCOUNT_TOT(NBIN)   i (W)   Total numbers (see also below)
C PERCENT(10,NBIN)   r (W)   Percentages of the unique data in bins (see 
C                            also below)
C PERCENT_TOT(NBIN)  r (W)   Percentage totals  (see also below)
C IERR               i (W)   Error flag =0 OK, =1 no reflns. or no bins
C
C                            First index:
C
C                            = 1    No. of unique reflections
C                            = 2    No. of Laue (single or multiple)
C                            = 3    No. of singles (may also be multiples)    
C                            = 4    No. of multiples (may also be singles)
C                            = 5    No. of doubles (may also be otherwise)
C                            = 6    No. of triples (may also be otherwise)
C                            = 7    No. of higher mults. (may also be 
C                                   otherwise)
C                            = 8    No. with double as lowest multiplicity
C                            = 9    No. with triple as lowest multiplicity
C                            = 10   No. with higher mult as lowest 
C                                   multiplicity
CD-end
C
C====== Parameter statements
C 

C
C====== GLOBALS:
C
      EXTERNAL LFN_UNQ_BDAT
      INCLUDE 'lfn_unq.finc'
C
C====== FUNCTION TYPES:
C
      REAL STHLSQ
C
C====== LOCALS:
C
      INTEGER I
      INTEGER J
      INTEGER K
      INTEGER IH
      INTEGER IK
      INTEGER IL
      INTEGER NSING
      INTEGER NMULT
      INTEGER NSPAT
      INTEGER NCLEAR
      INTEGER NDOUBLE
      INTEGER NTRIPLE
      INTEGER NHIGHER
      INTEGER NPLUS
      INTEGER NMINUS
      REAL WIDTH
      REAL S
      REAL SMIN
      REAL SMAX

C     INTEGER I           !Loop through unique reflections
C     INTEGER J           !Loop through count types
C     INTEGER K           !Loop through bins or bin number
C     INTEGER IH          !'h' index
C     INTEGER IK          !'k' index
C     INTEGER IL          !'l' index
C     INTEGER NSING       !No. of occurrences as a single
C     INTEGER NMULT       !No. of occurrences as a multiple
C     INTEGER NSPAT       !No. of occurrences as spatially overlapped
C     INTEGER NCLEAR      !No. of occurrences as non-spatially overlapped
C     INTEGER NDOUBLE     !No. of occurrences as a double
C     INTEGER NTRIPLE     !No. of occurrences as a triple
C     INTEGER NHIGHER     !No. of occurrences as a higher multiple
C     INTEGER NPLUS       !No. of occurrences as I+
C     INTEGER NMINUS      !No. of occurrences as I-
C     REAL WIDTH          !Bin width
C     REAL S              !'s' value for current reflection
C     REAL SMIN           !Minimum 's' value for current bin
C     REAL SMAX           !Maximum 's' value for current bin
C
C-------------------------------------------------------------------------------
C
      IERR = 0
      IF (NBIN.LT.1) THEN
          IERR = 1
          RETURN
      END IF
      DO 20 J = 1,10
         NCOUNT_TOT(J) = 0
         PERCENT_TOT(J) = 0.0
         DO 10 K = 1, NBIN
            NCOUNT(J,K) = 0
            PERCENT(J,K) = 0.0
10       CONTINUE
20    CONTINUE
      IF (NUM_UNQ.LE.0) THEN
         IERR = 1
         RETURN
      END IF
      WIDTH = (S_MAX - S_MIN) / NBIN
      DO 120 K = 1, NBIN
         SMIN = S_MIN + (K-1)*WIDTH
         SMAX = S_MIN + K*WIDTH
         RESMIN(K) = SQRT (1.0/SMIN)
         RESMAX(K) = SQRT (1.0/SMAX)
120   CONTINUE
      DO 150 I = 1, NUM_UNQ
         CALL LFN_UNQ_HKL (I, IH, IK, IL)
         S = 4.0*STHLSQ (IH, IK, IL)
         K = NBIN*(S-S_MIN)/(S_MAX-S_MIN) + 1
         IF (K.LT.1) K = 1
         IF (K.GT.NBIN) K = NBIN
         NCOUNT(1,K) = NCOUNT(1,K) + 1
         NCOUNT_TOT(1) = NCOUNT_TOT(1) + 1
         CALL LFN_UNQ_GET (I, NSING, NMULT, NDOUBLE, NTRIPLE, NHIGHER,
     +                     NPLUS, NMINUS, NCLEAR, NSPAT)
         IF (.NOT.SPAT.AND.NCLEAR.EQ.0) GO TO 150
         IF (NSING.GT.0.OR.NMULT.GT.0) THEN
            NCOUNT(2,K) = NCOUNT(2,K) + 1
            NCOUNT_TOT(2) = NCOUNT_TOT(2) + 1
         END IF
         IF (NSING.GT.0) THEN
            NCOUNT(3,K) = NCOUNT(3,K) + 1
            NCOUNT_TOT(3) = NCOUNT_TOT(3) + 1
         END IF
         IF (NMULT.GT.0) THEN
            NCOUNT(4,K) = NCOUNT(4,K) + 1
            NCOUNT_TOT(4) = NCOUNT_TOT(4) + 1
         END IF
         IF (NDOUBLE.GT.0) THEN
            NCOUNT(5,K) = NCOUNT(5,K) + 1
            NCOUNT_TOT(5) = NCOUNT_TOT(5) + 1
         END IF
         IF (NTRIPLE.GT.0) THEN
            NCOUNT(6,K) = NCOUNT(6,K) + 1
            NCOUNT_TOT(6) = NCOUNT_TOT(6) + 1
         END IF
         IF (NHIGHER.GT.0) THEN
            NCOUNT(7,K) = NCOUNT(7,K) + 1
            NCOUNT_TOT(7) = NCOUNT_TOT(7) + 1
         END IF
         IF (NSING.EQ.0) THEN
            IF (NDOUBLE.GT.0) THEN
               NCOUNT(8,K) = NCOUNT(8,K) + 1
               NCOUNT_TOT(8) = NCOUNT_TOT(8) + 1
            ELSE IF (NTRIPLE.GT.0) THEN
               NCOUNT(9,K) = NCOUNT(9,K) + 1
               NCOUNT_TOT(9) = NCOUNT_TOT(9) + 1
            ELSE IF (NHIGHER.GT.0) THEN
               NCOUNT(10,K) = NCOUNT(10,K) + 1
               NCOUNT_TOT(10) = NCOUNT_TOT(10) + 1
            END IF
         END IF
150   CONTINUE
      DO 200 K = 1, NBIN
         PERCENT(1,K) = 100.0
         DO 180 J = 2,10
            IF (NCOUNT(1,K).GT.0) 
     +      PERCENT(J,K) = 100.0*FLOAT(NCOUNT(J,K))/FLOAT(NCOUNT(1,K)) 
180      CONTINUE
200   CONTINUE
      PERCENT_TOT(1) = 100.0
      DO 210 J = 2,10
         IF (NCOUNT_TOT(1).GT.0) 
     +      PERCENT_TOT(J) = 100.0*FLOAT(NCOUNT_TOT(J))
     +                       / FLOAT(NCOUNT_TOT(1))
210   CONTINUE
      RETURN
      END
