
C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LSM_CHEB_2D_VAL  **
C**************************
C
C **** LSM SERVICE ROUTINE ONLY ****
C       
       REAL FUNCTION LSM_CHEB_2D_VAL (XMIN, XMAX, YMIN, YMAX, C, N, M,  
     +                            X, Y, IERR)
C
C
       INCLUDE 'implicit_none.finc'
C
C
C Purpose: Evaluate Chebyshev function value
C
C Author:  Steffi Arzt, John Campbell, July 1997
C
C Arguments:
C
       DOUBLE PRECISION XMIN
       DOUBLE PRECISION XMAX
       DOUBLE PRECISION YMIN
       DOUBLE PRECISION YMAX
       DOUBLE PRECISION C(*)
       INTEGER N
       INTEGER M
       DOUBLE PRECISION X
       DOUBLE PRECISION Y
       INTEGER IERR

C Parameters:
C  XMIN      (R)    Minimum 'x' used in polynomials calculation
C  XMAX      (R)    Maximum 'x' used in polynomials calcualtion
C  YMIN      (R)    Minimum 'y' used in polynomials calculation
C  YMAX      (R)    Maximum 'y' used in polynomials calcualtion
C  C         (R)    The Chebyshev polynomial coefficients. (N+1)*(M+1)
C                   numbers stored in a 1 D array with M being the
C                   faster moving index and N the slower moving index
C                   C(0,0), C(0,1) ... C(0,M)
C                   C(1,0), C(1,1) ... C(1,M)
C                   .
C                   .
C                   C(N,0), C(N,1) ... C(N,M)
C  N         (R)    Polynomial order in 'x' direction
C  M         (R)    Polynomial order in 'y' direction
C  X         (R)    The value of 'x' at which the function is to be evaluated
C  Y         (R)    The value of 'y' at which the function is to be evaluated
C  IERR      (W)    Error flag =0 OK, 
C                   =1 x, y outside range XMIN to XMAX, YMIN to YMAX 
C                   =2 polynomial order N or M outside range of routine 
C                   (value of 0.0 returned if IERR.NE.0)
C
C 
C
C====== PARAMETERS:
C
      INCLUDE 'limits.finc'
C
C====== GLOBALS:
C

C
C====== FUNCTION TYPES:
C
      REAL LSM_CHEBVAL
C
C====== LOCALS:
C
      INTEGER I
      INTEGER J
      DOUBLE PRECISION CI(MAXCOEFFS+1)
      DOUBLE PRECISION CJ(MAXCOEFFS+1)
 
C
C-------------------------------------------------------------------------------
C
      IERR = 0
      LSM_CHEB_2D_VAL = 0.0
      IF (N.GT.MAXCOEFFS+1.OR.M.GT.MAXCOEFFS+1) THEN
         IERR = 2
         RETURN
      END IF
      IF (((X-XMIN)*(X-XMAX)).GT.0.0) THEN
         IERR = 1
         RETURN
      END IF
      IF (((Y-YMIN)*(Y-YMAX)).GT.0.0) THEN
         IERR = 1
         RETURN
      END IF

      DO 100 I = 0, N
         DO 50 J = 0, M
            CJ(J+1) = C(I*(M+1)+J+1)
 50      CONTINUE
         CI(I+1) = LSM_CHEBVAL (YMIN, YMAX, CJ, M+1, Y)
 100  CONTINUE
      LSM_CHEB_2D_VAL = LSM_CHEBVAL (XMIN, XMAX, CI, N+1, X)
      RETURN
      END
