
C LAST UPDATE:
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C*******************************
C**     LSM_SELECT_SCREFS     **
C*******************************
C
C
CD-Routine: Select reflection types - LSM_SELECT_SCREFS
C This routine is used to select the types of scaleable reflection that are to
C be retrieved from a Laue Integrated Reflections List (LIRL). This must
C be called prior to using routines such as LSM_NUM_NEXT or LSM_NEXT_REFLN
C and the LSM service routines LSM_NEXT_REFOBS. Any reflections which
C are flagged in the LIRL as not measured, bad or outliers will be omitted
C and any reflections, for which sclaing parameters lie outside the ranges
C defined, will also be omitted on retrieval. Remember also to select the
C required packs/plates using LSM_SELECT_PKPL and associated routines.
CD-end
CD-Fortran:
      SUBROUTINE LSM_SELECT_SCREFS (SIGN_SEP, REFERENCE, SIGMA_CUT,
     +                              SPOV, OVLD)
CD-end
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Select reflection types for retrieval from LIRL
C
C Author:  Steffi Arzt, John Campbell, July 1997
C
C Arguments:
C
C
      LOGICAL SIGN_SEP
      LOGICAL REFERENCE
      REAL SIGMA_CUT
      LOGICAL SPOV
      LOGICAL OVLD
C
CD-Parameters:
C  SIGN_SEP    l (R)   If .true. the I+ and I- measurements will be returned
C                      as separate reflection sets; if .false. all symmetry
C                      equivalents bot I+ and I- will be returned together.
C  REFERENCE   l (R)   If .true. then only reflections which have a
C                      reference intensity stored will be returned;
C                      if .false., reflections will be returned whether
C                      or not a reference intensity is present.
C  SIGMA_CUT   r (R)   Omit reflections for which the intensity I is
C                      less than SIGMA_CUT*sig(I).
C  SPOV        l (R)   Flag = .true.  include spatially overlapped
C                                     reflections which have been
C                                     integrated,
C                           = .false. do not.
C  OVLD        l (R)   Flag = .true.  include intensity overloads,
C                           = .false. do not.
CD-end
C
C Implementation note: Sets 'select required' flag 
C
C
C====== PARAMETERS:
C
      INCLUDE 'limits.finc'
C
C====== GLOBALS:
C
      INCLUDE 'use_reflns.finc'
      INCLUDE 'lsm_flags.finc'
C
C====== LOCALS:
C
C
C-------------------------------------------------------------------------------
C
      SIGN_SEP_USE = SIGN_SEP
      REFINT_USE = REFERENCE
      SIGCUT_USE = SIGMA_CUT
      SPOV_USE = SPOV
      OVLD_USE = OVLD
      SELECT_REQUIRED = .TRUE.
      RETURN
      END
